content property

  1. @override
String get content
override

Store the content that will be written to the file in a String or Future <String> in that variable. It is used to fill the file created by path.

Implementation

@override
String get content => '''
// DO NOT EDIT. This is code generated via package:sm_get_cli/sm_get_cli.dart

// ignore_for_file: lines_longer_than_80_chars, constant_identifier_names
// ignore: avoid_classes_with_only_static_members
class ${_className ?? 'AppTranslation'} {

\tstatic Map<String, Map<String, String>> translations = {
$_translationsKeys
\t};

}

class LocaleKeys {
LocaleKeys._();
$_keys
}

class Locales {
\t$_locales
}
''';