BindingSample class

Sample file from Module_Binding file creation.

Inheritance

Constructors

BindingSample(String path, String _fileName, String _bindingName, String _controllerDir, bool _isServer, {bool overwrite = false, bool isVersion5 = false})

Properties

content String
Store the content that will be written to the file in a String or Future <String> in that variable. It is used to fill the file created by path.
no setteroverride
customContent String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isVersion5 bool
final
overwrite bool
If the file is found in the path, it can be ignored or overwritten. If overrite = false, the source file will not be changed. The default is false.
getter/setter pairinherited
path String
The path where the sample file will be added
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({bool skipFormatter = false}) File
This function will create the file in path with the content of content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited