content property

  1. @override
String get content
override

Store the content that will be written to the file in a String or Future <String> in that variable. It is used to fill the file created by path.

Implementation

@override
String get content => '''$_import
import 'package:${PubspecUtils.projectName}/$_controllerDir';

class $_bindingName extends Binding${isVersion5 ? '' : 's'} {
@override
${isVersion5 ? 'List<Bind>' : 'void'} dependencies() {
  ${isVersion5 ? "return [\nBind" : "Get"}.lazyPut<${_fileName.pascalCase}Controller>(
    () => ${_fileName.pascalCase}Controller(),
  )${isVersion5 ? ",\n]" : ""};
}
}
''';