content property

  1. @override
String get content
override

Store the content that will be written to the file in a String or Future <String> in that variable. It is used to fill the file created by path.

Implementation

@override
String get content => '''part of 'app_pages.dart';
// DO NOT EDIT. This is code generated via package:sm_get_cli/sm_get_cli.dart

abstract class Routes{
Routes._();

}

abstract class _Paths {

_Paths._();

}

''';