content property

String get content

Store the content that will be written to the file in a String or Future <String> in that variable. It is used to fill the file created by path.

Implementation

String get content;